@@ -75,14 +75,8 @@ midori_transferbar_download_notify_progress_cb (WebKitDownload* download,
                                                 GParamSpec*     pspec,
                                                 GtkWidget*      progress)
 {
-    gchar* current;
-    gchar* total;
-    gchar* size_text;
+    gchar* tooltip;
     gchar* text;
-    gchar* transfer;
-    gdouble* last_time;
-    guint64* last_size;
-    gdouble timestamp;
     guint64 size;
 
     gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress),
@@ -96,31 +90,12 @@ midori_transferbar_download_notify_progress_cb (WebKitDownload* download,
         return;
     }
 
-    current = g_format_size_for_display (webkit_download_get_current_size (download));
-    total = g_format_size_for_display (webkit_download_get_total_size (download));
-    last_time = g_object_get_data (G_OBJECT (download), "last-time");
-    last_size = g_object_get_data (G_OBJECT (download), "last-size");
-    timestamp = webkit_download_get_elapsed_time (download);
-    if (timestamp != *last_time)
-        transfer = g_format_size_for_display ((size - *last_size) / (timestamp - *last_time));
-    else
-        /* i18n: Unknown number of bytes, used for transfer rate like ?B/s */
-        transfer = g_strdup (_("?B"));
-    /* i18n: Download tooltip, 4KB of 43MB, 130KB/s */
-    size_text = g_strdup_printf (_("%s of %s, %s/s"), current, total, transfer);
-    if (timestamp - *last_time > 5.0)
-    {
-        *last_time = timestamp;
-        *last_size = size;
-    }
-    g_free (current);
-    g_free (total);
-    text = g_strdup_printf ("%s (%s)",
-        gtk_progress_bar_get_text (GTK_PROGRESS_BAR (progress)),
-        size_text);
+    tooltip = midori_download_prepare_tooltip_text (download);
+    text = g_strdup_printf ("%s\n%s",
+        gtk_progress_bar_get_text (GTK_PROGRESS_BAR (progress)), tooltip);
     gtk_widget_set_tooltip_text (progress, text);
-    g_free (size_text);
-    g_free (transfer);
+
+    g_free (tooltip);
     g_free (text);
 }
 
@@ -165,9 +140,9 @@ midori_transferbar_download_notify_status_cb (WebKitDownload* download,
             #if WEBKIT_CHECK_VERSION (1, 1, 14)
             request = webkit_download_get_network_request (download);
             original_uri = g_object_get_data (G_OBJECT (request), "midori-original-uri");
-            #else
-            original_uri = webkit_download_get_uri (download);
+            if (!original_uri)
             #endif
+                original_uri = webkit_download_get_uri (download);
             fingerprint = g_strsplit (original_uri, "#!md5!", 2);
             if (fingerprint && fingerprint[0] && fingerprint[1])
             {
